@@ -83,8 +83,10 @@ if (!mapboxgl.supported()) {
                 accessToken: mapboxgl.accessToken,
                 mapboxgl: mapboxgl,
                 localGeocoder: coordinatesGeocoder,
-
             });
+            if(map_attrs[id].language !== "auto")
+                geocoder.setLanguage(map_attrs[id].language);
+
             geocoders[id] = geocoder;
             map.getCanvas().style.cursor = map_attrs[id].cursor_style;
             if (!map_attrs[id].rotate) {
@@ -127,14 +129,14 @@ if (!mapboxgl.supported()) {
                     .addTo(map);
 
 
-                var url = "https://api.mapbox.com/geocoding/v5/mapbox.places/" + translate_to_string(e.lngLat) + ".json?access_token=" + mapboxgl.accessToken;
+                var url = "https://api.mapbox.com/geocoding/v5/mapbox.places/" + translate_to_string(e.lngLat) + ".json?access_token=" + mapboxgl.accessToken  + "&language=" + geocoder.getLanguage();
                 $.get(url, function (data) {
                     try {
                         reverse_name = data.features[0].place_name;
                     }
                     catch
                         (e) {
-                        reverse_name = "undefined address";
+                        reverse_name = map_attrs[id].message_404;
                     }
                     geocoder.setInput(reverse_name);
                     $(document).trigger("reverse-geocode", [id, reverse_name,]);
